@@ -352,8 +352,8 @@ impl App {
                 match result {
                     Ok((game_id, color)) => {
                         log::info!("Found Lichess game: {} with color {:?}", game_id, color);
-                        // For new games from seek, initial_move_count is 0
-                        self.setup_lichess_game(game_id, color, 0);
+                        // Use the helper function to set up the game with state
+                        self.setup_lichess_game_with_state(game_id, color, None);
                     }
                     Err(e) => {
                         log::error!("Failed to seek Lichess game: {}", e);
@@ -365,17 +365,142 @@ impl App {
         }
     }
 
-    fn setup_lichess_game(&mut self, game_id: String, color: Color, initial_move_count: usize) {
+    /// Setup a Lichess game by fetching FEN and setting up board state
+    /// This handles the common logic for joining games (by code or from ongoing games list)
+    fn setup_lichess_game_with_state(
+        &mut self,
+        game_id: String,
+        color: Color,
+        initial_fen: Option<String>,
+    ) -> bool {
+        // Try to get FEN if not provided
+        let mut fen = initial_fen;
+
+        // If not provided, try to get FEN from ongoing games if available
+        if fen.is_none() {
+            fen = self
+                .ongoing_games
+                .iter()
+                .find(|g| g.game_id == game_id)
+                .map(|g| g.fen.clone());
+        }
+
+        // If still not found, try fetching ongoing games to get FEN
+        if fen.is_none() {
+            if let Some(token) = &self.lichess_token {
+                let client = crate::lichess::LichessClient::new(token.clone());
+                if let Ok(ongoing_games) = client.get_ongoing_games() {
+                    fen = ongoing_games
+                        .iter()
+                        .find(|g| g.game_id == game_id)
+                        .map(|g| g.fen.clone());
+                }
+            }
+        }
+
+        // If we have FEN, set up board from FEN
+        // Also try to get turn count to set initial_move_count correctly
+        if let Some(ref fen_str) = fen {
+            log::info!("Setting up game from FEN: {}", fen_str);
+
+            // Try to get turn count and last move from public API immediately
+            // This ensures the last move shows in green immediately when joining
+            let mut initial_move_count = 0;
+            let mut last_move_to_add: Option<String> = None;
+            if let Some(token) = &self.lichess_token {
+                let client = crate::lichess::LichessClient::new(token.clone());
+                match client.get_game_turn_count_and_last_move(&game_id) {
+                    Ok((turns, last_move)) => {
+                        initial_move_count = turns;
+                        last_move_to_add = last_move.clone();
+                        log::info!(
+                            "Got turn count from API: {} (half-moves), last move: {:?}",
+                            initial_move_count,
+                            last_move
+                        );
+                    }
+                    Err(e) => {
+                        log::warn!(
+                            "Failed to get game info: {} (last move may not show immediately)",
+                            e
+                        );
+                    }
+                }
+            }
+
+            match shakmaty::fen::Fen::from_ascii(fen_str.as_bytes()) {
+                Ok(fen_data) => {
+                    match fen_data
+                        .into_position::<shakmaty::Chess>(shakmaty::CastlingMode::Standard)
+                    {
+                        Ok(position) => {
+                            self.game.logic.game_board.position_history = vec![position];
+                            self.game.logic.game_board.move_history = vec![];
+                            self.game.logic.game_board.taken_pieces = vec![];
+                            self.game.logic.game_board.history_position_index = None;
+                            self.game.logic.sync_player_turn_with_position();
+                            // Send last move immediately if we have it, so it shows in green right away
+                            self.setup_lichess_game(
+                                game_id,
+                                color,
+                                initial_move_count,
+                                last_move_to_add,
+                            );
+                            return true;
+                        }
+                        Err(e) => {
+                            log::error!("Failed to parse FEN position: {}", e);
+                            self.error_message = Some(format!("Failed to parse FEN: {}", e));
+                            self.current_popup = Some(Popups::Error);
+                            return false;
+                        }
+                    }
+                }
+                Err(e) => {
+                    log::error!("Failed to parse FEN string: {}", e);
+                    self.error_message = Some(format!("Failed to parse FEN: {}", e));
+                    self.current_popup = Some(Popups::Error);
+                    return false;
+                }
+            }
+        }
+
+        // Final fallback: No FEN available (new game from seek)
+        // For new games from seek, initial_move_count is 0
+        log::info!("No FEN available, setting up as new game");
+        self.setup_lichess_game(game_id, color, 0, None);
+        true
+    }
+
+    fn setup_lichess_game(
+        &mut self,
+        game_id: String,
+        color: Color,
+        initial_move_count: usize,
+        immediate_last_move: Option<String>,
+    ) {
         if let Some(token) = &self.lichess_token {
             let client = LichessClient::new(token.clone());
             let (lichess_to_app_tx, lichess_to_app_rx) = channel::<String>();
             let (app_to_lichess_tx, app_to_lichess_rx) = channel::<String>();
             let (player_move_tx, player_move_rx) = channel::<()>();
 
-            // Start streaming game events
+            // Send last move immediately if we have it (before starting stream)
+            // This ensures it shows in green right away instead of waiting for first poll
+            if let Some(ref last_move) = immediate_last_move {
+                log::info!("Sending last move immediately: {}", last_move);
+                let _ = lichess_to_app_tx.send(last_move.clone());
+                // Also send INIT_MOVES to set the initial move count correctly
+                if initial_move_count > 0 {
+                    let _ = lichess_to_app_tx.send(format!("INIT_MOVES:{}", initial_move_count));
+                }
+            }
+
+            // Start streaming game events (clone the sender since it's moved)
+            let lichess_to_app_tx_clone = lichess_to_app_tx.clone();
             if let Err(e) = client.stream_game(
                 game_id.clone(),
-                lichess_to_app_tx,
+                lichess_to_app_tx_clone,
                 Some(color),
                 Some(player_move_rx),
             ) {
@@ -550,116 +675,8 @@ impl App {
                 fen
             );
 
-            // Fetch moves from board API to build history
-            // Try board API first, then fall back to PGN export API
-            let moves_string = if let Some(token) = &self.lichess_token {
-                let client = crate::lichess::LichessClient::new(token.clone());
-
-                // First try board API
-                match client.get_game_state_with_moves(&game_id) {
-                    Ok(moves) => {
-                        log::info!("Fetched moves from board API");
-                        Some(moves)
-                    }
-                    Err(e) => {
-                        log::warn!(
-                            "Failed to fetch moves from board API: {}, trying PGN export API...",
-                            e
-                        );
-
-                        // Fallback to PGN export API
-                        match client.get_game_pgn(&game_id) {
-                            Ok(pgn) => {
-                                log::info!("Successfully fetched PGN from export API");
-                                // Parse PGN to extract moves in UCI format
-                                match crate::lichess::LichessClient::parse_pgn_moves(&pgn) {
-                                    Ok(uci_moves) => {
-                                        let move_count = uci_moves.split_whitespace().count();
-                                        log::info!(
-                                            "Successfully parsed PGN ({} moves)",
-                                            move_count
-                                        );
-                                        Some(uci_moves)
-                                    }
-                                    Err(parse_err) => {
-                                        log::warn!(
-                                            "Failed to parse PGN moves: {}, will use FEN only",
-                                            parse_err
-                                        );
-                                        None
-                                    }
-                                }
-                            }
-                            Err(pgn_err) => {
-                                log::warn!(
-                                    "Failed to fetch PGN from export API for game {}: {}. This is expected for ongoing games - history will be built from stream.",
-                                    game_id,
-                                    pgn_err
-                                );
-                                None
-                            }
-                        }
-                    }
-                }
-            } else {
-                log::warn!("No Lichess token available, cannot fetch moves");
-                None
-            };
-
-            // If we have moves, apply them to build the history
-            if let Some(ref moves_str) = moves_string {
-                if !moves_str.trim().is_empty() {
-                    self.game
-                        .logic
-                        .game_board
-                        .reconstruct_history(moves_str, Some(&fen));
-
-                    // Sync the player turn with the position's turn
-                    self.game.logic.sync_player_turn_with_position();
-
-                    // Calculate initial move count (number of half-moves)
-                    let initial_move_count = self.game.logic.game_board.move_history.len();
-
-                    log::info!(
-                        "Setting up Lichess game with {} moves in history",
-                        initial_move_count
-                    );
-
-                    // Now set up the Lichess connection
-                    self.setup_lichess_game(game_id, color, initial_move_count);
-                    return;
-                }
-            }
-
-            // Fallback: No moves available or empty moves string
-            // Set up with FEN position directly
-            log::info!("No moves available, setting up game from FEN: {}", fen);
-            match shakmaty::fen::Fen::from_ascii(fen.as_bytes()) {
-                Ok(fen_data) => {
-                    match fen_data
-                        .into_position::<shakmaty::Chess>(shakmaty::CastlingMode::Standard)
-                    {
-                        Ok(position) => {
-                            self.game.logic.game_board.position_history = vec![position];
-                            self.game.logic.game_board.move_history = vec![];
-                            self.game.logic.game_board.taken_pieces = vec![];
-                            self.game.logic.game_board.history_position_index = None;
-                            self.game.logic.sync_player_turn_with_position();
-                            self.setup_lichess_game(game_id, color, 0);
-                        }
-                        Err(e) => {
-                            log::error!("Failed to parse FEN position: {}", e);
-                            self.error_message = Some(format!("Failed to parse FEN: {}", e));
-                            self.current_popup = Some(Popups::Error);
-                        }
-                    }
-                }
-                Err(e) => {
-                    log::error!("Failed to parse FEN string: {}", e);
-                    self.error_message = Some(format!("Failed to parse FEN: {}", e));
-                    self.current_popup = Some(Popups::Error);
-                }
-            }
+            // Use the helper function to set up the game with state (pass the FEN we already have)
+            self.setup_lichess_game_with_state(game_id, color, Some(fen));
         }
     }
 
@@ -1225,14 +1242,21 @@ impl App {
                 self.cycle_skin();
                 self.update_config();
             }
+            #[cfg(feature = "sound")]
             5 => {
                 // Toggle sound
                 self.sound_enabled = !self.sound_enabled;
                 crate::sound::set_sound_enabled(self.sound_enabled);
                 self.update_config();
             }
+            #[cfg(feature = "sound")]
             6 => self.toggle_help_popup(),
+            #[cfg(feature = "sound")]
             7 => self.current_page = Pages::Credit,
+            #[cfg(not(feature = "sound"))]
+            5 => self.toggle_help_popup(),
+            #[cfg(not(feature = "sound"))]
+            6 => self.current_page = Pages::Credit,
             _ => {}
         }
     }
