@@ -12,13 +12,10 @@ pub mod server;
 /// Event handler.
 pub mod handler;
 
-// Chess pieces structures
-pub mod pieces;
-
 // Game related structures
 pub mod game_logic;
 
-// Constats for the app
+// Constants for the app
 pub mod constants;
 
 // Utils methods for the board
@@ -26,3 +23,18 @@ pub mod utils;
 
 // Logging
 pub mod logging;
+
+// Chess pieces
+pub mod pieces;
+
+// Configuration
+pub mod config;
+
+// Skin
+pub mod skin;
+
+// Lichess
+pub mod lichess;
+
+// Sound effects
+pub mod sound;
