@@ -30,16 +30,20 @@ struct Args {
     /// Lichess API token
     #[arg(short, long)]
     lichess_token: Option<String>,
+    /// Disable sound effects
+    #[arg(long)]
+    no_sound: bool,
 }
 
 fn main() -> AppResult<()> {
-    // Used to enable mouse capture
+    // Parse the cli arguments first (this will handle --version and exit early if needed)
+    let args = Args::parse();
+
+    // Used to enable mouse capture (only after we know we're running the TUI)
     ratatui::crossterm::execute!(
         std::io::stdout(),
         ratatui::crossterm::event::EnableMouseCapture
     )?;
-    // Parse the cli arguments
-    let args = Args::parse();
 
     let config_dir = config_dir()?;
     let folder_path = config_dir.join("chess-tui");
@@ -177,6 +181,12 @@ fn main() -> AppResult<()> {
         app.lichess_token = Some(token.clone());
     }
 
+    // Command line no-sound flag takes precedence over configuration file
+    if args.no_sound {
+        app.sound_enabled = false;
+        chess_tui::sound::set_sound_enabled(false);
+    }
+
     // Setup logging
     if let Err(e) = logging::setup_logging(&folder_path, &app.log_level) {
         eprintln!("Failed to initialize logging: {}", e);
@@ -360,6 +370,11 @@ fn config_create(args: &Args, folder_path: &Path, config_path: &Path) -> AppResu
         config.bot_depth = Some(args.depth);
     }
 
+    // Always update sound_enabled if --no-sound flag is provided via command line (command line takes precedence)
+    if args.no_sound {
+        config.sound_enabled = Some(false);
+    }
+
     let toml_string = toml::to_string(&config)
         .expect("Failed to serialize config to TOML. This is a bug, please report it.");
     let mut file = File::create(config_path)?;
@@ -394,6 +409,7 @@ mod tests {
             engine_path: "test_engine_path".to_string(),
             depth: 10,
             lichess_token: None,
+            no_sound: false,
         };
 
         let config_dir = config_dir().unwrap();
